@@ -128,7 +128,7 @@ DirectoryServicesConfigurationPage::Private::Private(DirectoryServicesConfigurat
         auto groupBoxLayout = new QVBoxLayout{groupBox};
         groupBoxLayout->setContentsMargins({});
 
-        groupBoxLayout->addWidget(new QLabel(i18n("Please note that only one OpenPGP keyserver can be configured.")));
+        groupBoxLayout->addWidget(new QLabel(i18nc("@label:textbox", "Please note that only one OpenPGP keyserver can be configured.")));
 
         {
             mUseKeyServerCheckBox = new QCheckBox(i18nc("@label:checkbox", "Use OpenPGP keyserver"));
@@ -421,8 +421,8 @@ void DirectoryServicesConfigurationPage::Private::save()
         } else if (keyserver == QLatin1StringView{"none"}) {
             mOpenPGPServiceEntry->setStringValue(keyserver);
         } else {
-            const auto keyserverUrl = keyserver.contains(QLatin1StringView{"://"}) ? keyserver : (QLatin1String{"hkps://"} + keyserver);
-            mOpenPGPServiceEntry->setStringValue(keyserverUrl);
+            const auto keyserverValue = keyserver.contains(QLatin1Char{':'}) ? keyserver : (QLatin1String{"hkps://"} + keyserver);
+            mOpenPGPServiceEntry->setStringValue(keyserverValue);
         }
         mRetrieveKeysEntry->setBoolValue(mRetrieveKeysCheckBox->isChecked());
     }
