@@ -8,11 +8,15 @@
 */
 #pragma once
 
+#include "dialogs/certificateselectiondialog.h"
+
+#include <QList>
 #include <QWidget>
-#include <QVector>
 
 #include <gpgme++/global.h>
 
+#include <Libkleo/UserIDSelectionCombo>
+
 #include <memory>
 
 namespace GpgME
@@ -25,16 +29,11 @@ namespace Kleo
 class CertificateLineEdit;
 class KeyGroup;
 
-class SignEncryptWidget: public QWidget
+class SignEncryptWidget : public QWidget
 {
     Q_OBJECT
 public:
-    enum Operation {
-        NoOperation = 0x00,
-        Sign = 0x01,
-        Encrypt = 0x02,
-        SignAndEncrypt = Sign | Encrypt
-    };
+    enum Operation { NoOperation = 0x00, Sign = 0x01, Encrypt = 0x02, SignAndEncrypt = Sign | Encrypt };
     Q_DECLARE_FLAGS(Operations, Operation)
 
     /** If cmsSigEncExclusive is true CMS operations can be
@@ -56,11 +55,11 @@ public:
 
     /** Returns the selected signing key or a null key if signing
      * is disabled. */
-    GpgME::Key signKey() const;
+    GpgME::UserID signUserId() const;
 
     /** Returns the selected encrypt to self key or a null key if
      * encrypt to self is disabled. */
-    GpgME::Key selfKey() const;
+    GpgME::UserID selfUserId() const;
 
     /** Returns the operation based on the current selection. */
     Operations currentOp() const;
@@ -115,6 +114,7 @@ protected Q_SLOTS:
     void updateOp();
     void recipientsChanged();
     void certificateSelectionRequested(CertificateLineEdit *w);
+    void ownCertificateSelectionRequested(Kleo::Dialogs::CertificateSelectionDialog::Options options, UserIDSelectionCombo *combo);
 
 protected:
     void loadKeys();
@@ -132,7 +132,6 @@ private:
     class Private;
     const std::unique_ptr<Private> d;
 };
-
-Q_DECLARE_OPERATORS_FOR_FLAGS(SignEncryptWidget::Operations)
-
 } // namespace Kleo
+
+Q_DECLARE_OPERATORS_FOR_FLAGS(Kleo::SignEncryptWidget::Operations)
