@@ -11,8 +11,6 @@
 
 #include <crypto/task.h>
 
-#include <utils/pimpl_ptr.h>
-
 #include <gpgme++/global.h>
 
 #include <memory>
@@ -56,6 +54,7 @@ public:
     void setSign(bool sign);
     void setEncrypt(bool encrypt);
     void setDetachedSignature(bool detached);
+    bool detachedSignatureEnabled() const;
     void setEncryptSymmetric(bool symmetric);
     void setClearsign(bool clearsign);
     void setCreateArchive(bool archive);
@@ -73,7 +72,7 @@ private:
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
     Q_PRIVATE_SLOT(d, void slotResult(const GpgME::SigningResult &))
     Q_PRIVATE_SLOT(d, void slotResult(const GpgME::SigningResult &, const GpgME::EncryptionResult &))
     Q_PRIVATE_SLOT(d, void slotResult(const GpgME::EncryptionResult &))
@@ -81,5 +80,3 @@ private:
 
 }
 }
-
-
