@@ -121,7 +121,6 @@ UserIdsWidget::UserIdsWidget(QWidget *parent)
 {
     auto userIDsLayout = new QVBoxLayout{this};
     userIDsLayout->setContentsMargins({});
-    userIDsLayout->setSpacing(0);
 
     d->userIDTable = new TreeWidget{parent};
     d->userIDTable->setAccessibleName(i18n("User IDs"));
@@ -136,9 +135,6 @@ UserIdsWidget::UserIdsWidget(QWidget *parent)
 
     userIDsLayout->addWidget(d->userIDTable);
 
-    auto separator = new KSeparator(parent);
-    userIDsLayout->addWidget(separator);
-
     d->buttonRow = new QHBoxLayout;
 
     d->addUserIDBtn = new QPushButton(i18nc("@action:button", "Add User ID"), parent);
@@ -244,7 +240,7 @@ void UserIdsWidget::Private::setUpUserIDTable()
 {
     userIDTable->clear();
 
-    QStringList headers = {i18n("Email"), i18n("Name"), i18n("Trust Level"), i18n("Tags")};
+    QStringList headers = {i18n("Email"), i18n("Name"), i18n("Trust Level"), i18n("Tags"), i18n("Origin")};
     userIDTable->setColumnCount(headers.count());
     userIDTable->setColumnWidth(0, 200);
     userIDTable->setColumnWidth(1, 200);
@@ -283,6 +279,7 @@ void UserIdsWidget::Private::setUpUserIDTable()
         item->setData(3, Qt::DisplayRole, tags);
         item->setData(3, Qt::ToolTipRole, toolTip);
 
+        item->setData(4, Qt::DisplayRole, Formatting::origin(uid.origin()));
         userIDTable->addTopLevelItem(item);
     }
     userIDTable->restoreColumnLayout(QStringLiteral("UserIDTable"));
