@@ -9,21 +9,21 @@
 */
 #pragma once
 
-#include <QWidget>
+#include "smartcardwidget.h"
 
 class QLabel;
 
 namespace Kleo
 {
+class CardKeysView;
 class OpenPGPKeyCardWidget;
 
 namespace SmartCard
 {
-struct KeyPairInfo;
 class P15Card;
 }
 
-class P15CardWidget : public QWidget
+class P15CardWidget : public SmartCardWidget
 {
     Q_OBJECT
 public:
@@ -36,12 +36,10 @@ private:
     void searchPGPFpr(const std::string &fpr);
 
 private:
-    std::string mCardSerialNumber;
-    QLabel *mVersionLabel = nullptr;
-    QLabel *mSerialNumber = nullptr;
     QLabel *mStatusLabel = nullptr;
     QWidget *mOpenPGPKeysSection = nullptr;
     OpenPGPKeyCardWidget *mOpenPGPKeysWidget = nullptr;
+    CardKeysView *mCardKeysView = nullptr;
 };
 
 }
