@@ -11,8 +11,6 @@
 
 #include <QWidget>
 
-#include <utils/pimpl_ptr.h>
-
 #include <memory>
 
 class QLineEdit;
@@ -27,7 +25,7 @@ class SearchBar : public QWidget
     Q_OBJECT
 public:
     explicit SearchBar(QWidget *parent = nullptr, Qt::WindowFlags f = {});
-    ~SearchBar();
+    ~SearchBar() override;
 
     const std::shared_ptr<KeyFilter> &keyFilter() const;
 
@@ -48,11 +46,8 @@ Q_SIGNALS:
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
-    Q_PRIVATE_SLOT(d, void slotKeyFilterChanged(int))
-    Q_PRIVATE_SLOT(d, void listNotCertifiedKeys())
+    const std::unique_ptr<Private> d;
     Q_PRIVATE_SLOT(d, void showOrHideCertifyButton())
 };
 
 }
-
